@@ -36,9 +36,22 @@ NormalKernel <- R6Class("NormalKernel",
     #' \deqn{\int_a^b (f_X(u))^2 du}
     #' where X is the Distribution, \eqn{f_X} is its pdf and \eqn{a, b}
     #' are the distribution support limits.
-    pdfSquared2Norm = function(x = 0) {
-      # return((2 * sqrt(pi))^-1)
-      return((1 / (2 * sqrt(pi))) * exp(-(x / 2)^2)) # nolint
+    pdfSquared2Norm = function(x = 0, upper = Inf) {
+      xl = length(x)
+      ul = length(upper)
+      len = max(xl, ul)
+
+      ret <- numeric(len)
+      for (i in seq(len)) {
+        xi = x[ifelse(i %% xl == 0, xl, i %% xl)]
+        ui = upper[ifelse(i %% ul == 0, ul, i %% ul)]
+        if (ui == Inf) {
+          ret[i] <- (1 / (2 * sqrt(pi))) * exp(- (xi / 2)^2)
+        } else {
+          ret[i] <- exp(- (xi^2) / 4) / (4 * sqrt(pi)) *
+            (2 * pnorm((ui - xi / 2) * sqrt(2)) - 1 + 1)}
+      }
+      return(ret)
     },
 
     #' @description
@@ -46,7 +59,8 @@ NormalKernel <- R6Class("NormalKernel",
     #' \deqn{var_X = E[X^2] - E[X]^2}
     #' where \eqn{E_X} is the expectation of distribution X. If the distribution is multivariate the
     #' covariance matrix is returned.
-    variance = function() {
+    #' @param ... Unused.
+    variance = function(...) {
       return(1)
     }
   ),
