@@ -55,7 +55,8 @@ Arcsine <- R6Class("Arcsine",
     #' The arithmetic mean of a (discrete) probability distribution X is the expectation
     #' \deqn{E_X(X) = \sum p_X(x)*x}
     #' with an integration analogue for continuous distributions.
-    mean = function() {
+    #' @param ... Unused.
+    mean = function(...) {
       return((unlist(self$getParameterValue("upper")) + unlist(self$getParameterValue("lower"))) /
         2)
     },
@@ -88,7 +89,8 @@ Arcsine <- R6Class("Arcsine",
     #' \deqn{var_X = E[X^2] - E[X]^2}
     #' where \eqn{E_X} is the expectation of distribution X. If the distribution is multivariate the
     #' covariance matrix is returned.
-    variance = function() {
+    #' @param ... Unused.
+    variance = function(...) {
       ((unlist(self$getParameterValue("upper")) - unlist(self$getParameterValue("lower")))^2) / 8
     },
 
@@ -97,7 +99,8 @@ Arcsine <- R6Class("Arcsine",
     #' \deqn{sk_X = E_X[\frac{x - \mu}{\sigma}^3]}{sk_X = E_X[((x - \mu)/\sigma)^3]}
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
-    skewness = function() {
+    #' @param ... Unused.
+    skewness = function(...) {
       rep(0, length(self$getParameterValue("lower")))
     },
 
@@ -107,7 +110,8 @@ Arcsine <- R6Class("Arcsine",
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
     #' Excess Kurtosis is Kurtosis - 3.
-    kurtosis = function(excess = TRUE) {
+    #' @param ... Unused.
+    kurtosis = function(excess = TRUE, ...) {
       if (excess) {
         return(rep(-1.5, length(self$getParameterValue("lower"))))
       } else {
@@ -120,14 +124,16 @@ Arcsine <- R6Class("Arcsine",
     #' \deqn{- \sum (f_X)log(f_X)}
     #' where \eqn{f_X} is the pdf of distribution X, with an integration analogue for
     #' continuous distributions.
-    entropy = function(base = 2) {
+    #' @param ... Unused.
+    entropy = function(base = 2, ...) {
       rep(log(pi / 4, base), length(self$getParameterValue("lower")))
     },
 
     #' @description The probability generating function is defined by
     #' \deqn{pgf_X(z) = E_X[exp(z^x)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    pgf = function(z) {
+    #' @param ... Unused.
+    pgf = function(z, ...) {
       NaN
     },
 
