@@ -60,7 +60,8 @@ Bernoulli <- R6Class("Bernoulli",
     #' The arithmetic mean of a (discrete) probability distribution X is the expectation
     #' \deqn{E_X(X) = \sum p_X(x)*x}
     #' with an integration analogue for continuous distributions.
-    mean = function() {
+    #' @param ... Unused.
+    mean = function(...) {
       unlist(self$getParameterValue("prob"))
     },
 
@@ -116,7 +117,8 @@ Bernoulli <- R6Class("Bernoulli",
     #' \deqn{var_X = E[X^2] - E[X]^2}
     #' where \eqn{E_X} is the expectation of distribution X. If the distribution is multivariate the
     #' covariance matrix is returned.
-    variance = function() {
+    #' @param ... Unused.
+    variance = function(...) {
       unlist(self$getParameterValue("prob")) * unlist(self$getParameterValue("qprob"))
     },
 
@@ -125,7 +127,8 @@ Bernoulli <- R6Class("Bernoulli",
     #' \deqn{sk_X = E_X[\frac{x - \mu}{\sigma}^3]}{sk_X = E_X[((x - \mu)/\sigma)^3]}
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
-    skewness = function() {
+    #' @param ... Unused.
+    skewness = function(...) {
       (1 - (2 * unlist(self$getParameterValue("prob")))) / self$stdev()
     },
 
@@ -135,7 +138,8 @@ Bernoulli <- R6Class("Bernoulli",
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
     #' Excess Kurtosis is Kurtosis - 3.
-    kurtosis = function(excess = TRUE) {
+    #' @param ... Unused.
+    kurtosis = function(excess = TRUE, ...) {
       exkurtosis <- (1 - (6 * unlist(self$getParameterValue("prob")) *
         unlist(self$getParameterValue("qprob")))) / self$variance()
       if (excess) {
@@ -150,7 +154,8 @@ Bernoulli <- R6Class("Bernoulli",
     #' \deqn{- \sum (f_X)log(f_X)}
     #' where \eqn{f_X} is the pdf of distribution X, with an integration analogue for
     #' continuous distributions.
-    entropy = function(base = 2) {
+    #' @param ... Unused.
+    entropy = function(base = 2, ...) {
       prob <- unlist(self$getParameterValue("prob"))
       qprob <- 1 - prob
 
@@ -160,7 +165,8 @@ Bernoulli <- R6Class("Bernoulli",
     #' @description The moment generating function is defined by
     #' \deqn{mgf_X(t) = E_X[exp(xt)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    mgf = function(t) {
+    #' @param ... Unused.
+    mgf = function(t, ...) {
       prob <- self$getParameterValue("prob")
       qprob <- 1 - prob
 
@@ -170,7 +176,8 @@ Bernoulli <- R6Class("Bernoulli",
     #' @description The characteristic function is defined by
     #' \deqn{cf_X(t) = E_X[exp(xti)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    cf = function(t) {
+    #' @param ... Unused.
+    cf = function(t, ...) {
       prob <- self$getParameterValue("prob")
       qprob <- 1 - prob
 
@@ -180,7 +187,8 @@ Bernoulli <- R6Class("Bernoulli",
     #' @description The probability generating function is defined by
     #' \deqn{pgf_X(z) = E_X[exp(z^x)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    pgf = function(z) {
+    #' @param ... Unused.
+    pgf = function(z, ...) {
       prob <- self$getParameterValue("prob")
       qprob <- 1 - prob
       return(qprob + (prob * z))
