@@ -60,7 +60,7 @@ EmpiricalMV <- R6Class("EmpiricalMV",
       private$.parameters <- ParameterSet$new(
         id = "data",
         value = list(data),
-        support = UniversalSet$new(),
+        support = Universal$new(),
         settable = FALSE,
         description = "Data"
       )
