@@ -63,7 +63,8 @@ Frechet <- R6Class("Frechet",
     #' The arithmetic mean of a (discrete) probability distribution X is the expectation
     #' \deqn{E_X(X) = \sum p_X(x)*x}
     #' with an integration analogue for continuous distributions.
-    mean = function() {
+    #' @param ... Unused.
+    mean = function(...) {
       shape <- unlist(self$getParameterValue("shape"))
       minimum <- unlist(self$getParameterValue("minimum"))
       scale <- unlist(self$getParameterValue("scale"))
@@ -101,7 +102,8 @@ Frechet <- R6Class("Frechet",
     #' \deqn{var_X = E[X^2] - E[X]^2}
     #' where \eqn{E_X} is the expectation of distribution X. If the distribution is multivariate the
     #' covariance matrix is returned.
-    variance = function() {
+    #' @param ... Unused.
+    variance = function(...) {
       shape <- unlist(self$getParameterValue("shape"))
       minimum <- unlist(self$getParameterValue("minimum"))
       scale <- unlist(self$getParameterValue("scale"))
@@ -116,7 +118,8 @@ Frechet <- R6Class("Frechet",
     #' \deqn{sk_X = E_X[\frac{x - \mu}{\sigma}^3]}{sk_X = E_X[((x - \mu)/\sigma)^3]}
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
-    skewness = function() {
+    #' @param ... Unused.
+    skewness = function(...) {
       shape <- unlist(self$getParameterValue("shape"))
       minimum <- unlist(self$getParameterValue("minimum"))
       scale <- unlist(self$getParameterValue("scale"))
@@ -134,7 +137,8 @@ Frechet <- R6Class("Frechet",
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
     #' Excess Kurtosis is Kurtosis - 3.
-    kurtosis = function(excess = TRUE) {
+    #' @param ... Unused.
+    kurtosis = function(excess = TRUE, ...) {
       shape <- unlist(self$getParameterValue("shape"))
       minimum <- unlist(self$getParameterValue("minimum"))
       scale <- unlist(self$getParameterValue("scale"))
@@ -154,7 +158,8 @@ Frechet <- R6Class("Frechet",
     #' \deqn{- \sum (f_X)log(f_X)}
     #' where \eqn{f_X} is the pdf of distribution X, with an integration analogue for
     #' continuous distributions.
-    entropy = function(base = 2) {
+    #' @param ... Unused.
+    entropy = function(base = 2, ...) {
       shape <- unlist(self$getParameterValue("shape"))
       minimum <- unlist(self$getParameterValue("minimum"))
       scale <- unlist(self$getParameterValue("scale"))
@@ -165,7 +170,8 @@ Frechet <- R6Class("Frechet",
     #' @description The probability generating function is defined by
     #' \deqn{pgf_X(z) = E_X[exp(z^x)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    pgf = function(z) {
+    #' @param ... Unused.
+    pgf = function(z, ...) {
       return(NaN)
     },
 
