@@ -68,7 +68,8 @@ Hypergeometric <- R6Class("Hypergeometric",
     #' The arithmetic mean of a (discrete) probability distribution X is the expectation
     #' \deqn{E_X(X) = \sum p_X(x)*x}
     #' with an integration analogue for continuous distributions.
-    mean = function() {
+    #' @param ... Unused.
+    mean = function(...) {
       unlist(self$getParameterValue("draws")) * unlist(self$getParameterValue("successes")) /
         unlist(self$getParameterValue("size"))
     },
@@ -89,7 +90,8 @@ Hypergeometric <- R6Class("Hypergeometric",
     #' \deqn{var_X = E[X^2] - E[X]^2}
     #' where \eqn{E_X} is the expectation of distribution X. If the distribution is multivariate the
     #' covariance matrix is returned.
-    variance = function() {
+    #' @param ... Unused.
+    variance = function(...) {
       draws <- unlist(self$getParameterValue("draws"))
       successes <- unlist(self$getParameterValue("successes"))
       size <- unlist(self$getParameterValue("size"))
@@ -101,7 +103,8 @@ Hypergeometric <- R6Class("Hypergeometric",
     #' \deqn{sk_X = E_X[\frac{x - \mu}{\sigma}^3]}{sk_X = E_X[((x - \mu)/\sigma)^3]}
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
-    skewness = function() {
+    #' @param ... Unused.
+    skewness = function(...) {
       draws <- unlist(self$getParameterValue("draws"))
       successes <- unlist(self$getParameterValue("successes"))
       size <- unlist(self$getParameterValue("size"))
@@ -115,7 +118,8 @@ Hypergeometric <- R6Class("Hypergeometric",
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
     #' Excess Kurtosis is Kurtosis - 3.
-    kurtosis = function(excess = TRUE) {
+    #' @param ... Unused.
+    kurtosis = function(excess = TRUE, ...) {
       draws <- unlist(self$getParameterValue("draws"))
       successes <- unlist(self$getParameterValue("successes"))
       size <- unlist(self$getParameterValue("size"))
