@@ -66,7 +66,8 @@ Multinomial <- R6Class("Multinomial",
     #' The arithmetic mean of a (discrete) probability distribution X is the expectation
     #' \deqn{E_X(X) = \sum p_X(x)*x}
     #' with an integration analogue for continuous distributions.
-    mean = function() {
+    #' @param ... Unused.
+    mean = function(...) {
       size <- self$getParameterValue("size")
       probs <- self$getParameterValue("probs")
 
@@ -86,7 +87,8 @@ Multinomial <- R6Class("Multinomial",
     #' \deqn{var_X = E[X^2] - E[X]^2}
     #' where \eqn{E_X} is the expectation of distribution X. If the distribution is multivariate the
     #' covariance matrix is returned.
-    variance = function() {
+    #' @param ... Unused.
+    variance = function(...) {
       size <- self$getParameterValue("size")
       probs <- self$getParameterValue("probs")
 
@@ -109,7 +111,8 @@ Multinomial <- R6Class("Multinomial",
     #' \deqn{sk_X = E_X[\frac{x - \mu}{\sigma}^3]}{sk_X = E_X[((x - \mu)/\sigma)^3]}
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
-    skewness = function() {
+    #' @param ... Unused.
+    skewness = function(...) {
       rep(NaN, length(self$getParameterValue("size")))
     },
 
@@ -119,7 +122,8 @@ Multinomial <- R6Class("Multinomial",
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
     #' Excess Kurtosis is Kurtosis - 3.
-    kurtosis = function(excess = TRUE) {
+    #' @param ... Unused.
+    kurtosis = function(excess = TRUE, ...) {
       rep(NaN, length(self$getParameterValue("size")))
     },
 
@@ -128,7 +132,8 @@ Multinomial <- R6Class("Multinomial",
     #' \deqn{- \sum (f_X)log(f_X)}
     #' where \eqn{f_X} is the pdf of distribution X, with an integration analogue for
     #' continuous distributions.
-    entropy = function(base = 2) {
+    #' @param ... Unused.
+    entropy = function(base = 2, ...) {
       size <- self$getParameterValue("size")
       probs <- self$getParameterValue("probs")
 
@@ -169,7 +174,8 @@ Multinomial <- R6Class("Multinomial",
     #' @description The moment generating function is defined by
     #' \deqn{mgf_X(t) = E_X[exp(xt)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    mgf = function(t) {
+    #' @param ... Unused.
+    mgf = function(t, ...) {
       probs <- self$getParameterValue("probs")
       checkmate::assert(length(t) == length(probs))
       return(sum(exp(t) * probs)^self$getParameterValue("size"))
@@ -178,7 +184,8 @@ Multinomial <- R6Class("Multinomial",
     #' @description The characteristic function is defined by
     #' \deqn{cf_X(t) = E_X[exp(xti)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    cf = function(t) {
+    #' @param ... Unused.
+    cf = function(t, ...) {
       probs <- self$getParameterValue("probs")
       checkmate::assert(length(t) == length(probs))
       return(sum(exp(1i * t) * probs)^self$getParameterValue("size"))
@@ -187,7 +194,8 @@ Multinomial <- R6Class("Multinomial",
     #' @description The probability generating function is defined by
     #' \deqn{pgf_X(z) = E_X[exp(z^x)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    pgf = function(z) {
+    #' @param ... Unused.
+    pgf = function(z, ...) {
       probs <- self$getParameterValue("probs")
       checkmate::assert(length(z) == length(probs))
       return(sum(probs * z)^self$getParameterValue("size"))
